@@ -20,6 +20,6 @@ extra = {
     'test_dict': {'a': 1, 'b': set(['a'])},
     'test_float': 1.23,
     'test_integer': 123,
-    'test_list': [1, 2, '3'],
+    'test_list': [1, 2, 3],
 }
 test_logger.info('python-logstash: test extra fields', extra=extra)
